@@ -53,6 +53,18 @@ GMLEnvelopeWithTimePeriod <- R6Class("GMLEnvelopeWithTimePeriod",
        }
      },
      
+     #decode
+     decode = function(xml){
+        super$decode(xml)
+        #backward compatibility in case of GML < 3
+        children <- xmlChildren(xml)
+        children <- children[names(children)=="timePosition"]
+        if(length(children)>0){
+          self$beginPosition <- as.POSIXct(strptime(unlist(strsplit(xmlValue(children[[1]]), " ")), "%Y-%m-%dT%H:%M:%S"), tz = "") 
+          self$endPosition <- as.POSIXct(strptime(unlist(strsplit(xmlValue(children[[2]]), " ")), "%Y-%m-%dT%H:%M:%S"), tz = "")
+        }
+     },
+     
      #setBeginPosition
      setBeginPosition = function(beginPosition){
        if(!all(class(beginPosition)==c("POSIXct","POSIXt")) | is(beginPosition, "Date")){
